==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ts/Shape_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Line</name>
    <message>
        <source>Line Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Linie&quot;
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation type="obsolete">Narzędzia linii</translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Linie&quot;</translatorcomment>
        <translation type="obsolete">Pokaż menu &quot;Linie&quot;</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Linia
&amp;Liniowy</translatorcomment>
        <translation type="obsolete">&amp;Linia</translation>
    </message>
</context>
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+74"/>
        <source>Shape Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translation type="obsolete">Pokaż menu &quot;Linie&quot;</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ts/Shape_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Line</name>
    <message>
        <source>Line Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Linie&quot;
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation type="obsolete">Narzędzia linii</translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Linie&quot;</translatorcomment>
        <translation type="obsolete">Pokaż menu &quot;Linie&quot;</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Linia
&amp;Liniowy</translatorcomment>
        <translation type="obsolete">&amp;Linia</translation>
    </message>
</context>
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+75"/>
        <source>Shape Tools</source>
        <translation>Narzędzia figur</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation>Wyświetla narzędzia figur</translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translation type="obsolete">Pokaż menu &quot;Linie&quot;</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation>&amp;Figura</translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation>Utworzenie linii łamanej</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fill</source>
        <translation>Wypełnienie</translation>
    </message>
</context>
</TS>
